==> estateplat-common-1.2.4-20210415.090730-716-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhWsxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

@Table(name = "GX_YH_WSXX")
public class GxYhWsxx implements Serializable {
    @Id
    private String wsxxid;//主键
    private String xtsphm;
    private String htbh;
    private String nsrsbh;
    private String nsrmc;
    private String zrfccsfbz;
    private String dzsphm;
    private String pzzldm;
    private String pzzgdm;
    private String pzhm;
    private String skssqq;
    private String skssqz;
    private String zsxmdm;
    private String zspmdm;
    private String zszmdm;
    private String zsxmmc;
    private String zspmmc;
    private String zszmmc;
    private String jsyj;
    private String sl1;
    private String sjje;
    private String zgswskfjdm;
    private String zsswjgdm;
    private String skssswjgdm;
    private String zgswskfjmc;
    private String zsswjgmc;
    private String skssswjgmc;
    private String kjrq;
    private String bz;
    private String bjbh;

    public String getWsxxid() {
        return wsxxid;
    }

    public void setWsxxid(String wsxxid) {
        this.wsxxid = wsxxid;
    }

    public String getXtsphm() {
        return xtsphm;
    }

    public void setXtsphm(String xtsphm) {
        this.xtsphm = xtsphm;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getZrfccsfbz() {
        return zrfccsfbz;
    }

    public void setZrfccsfbz(String zrfccsfbz) {
        this.zrfccsfbz = zrfccsfbz;
    }

    public String getDzsphm() {
        return dzsphm;
    }

    public void setDzsphm(String dzsphm) {
        this.dzsphm = dzsphm;
    }

    public String getPzzldm() {
        return pzzldm;
    }

    public void setPzzldm(String pzzldm) {
        this.pzzldm = pzzldm;
    }

    public String getPzzgdm() {
        return pzzgdm;
    }

    public void setPzzgdm(String pzzgdm) {
        this.pzzgdm = pzzgdm;
    }

    public String getPzhm() {
        return pzhm;
    }

    public void setPzhm(String pzhm) {
        this.pzhm = pzhm;
    }

    public String getSkssqq() {
        return skssqq;
    }

    public void setSkssqq(String skssqq) {
        this.skssqq = skssqq;
    }

    public String getSkssqz() {
        return skssqz;
    }

    public void setSkssqz(String skssqz) {
        this.skssqz = skssqz;
    }

    public String getZsxmdm() {
        return zsxmdm;
    }

    public void setZsxmdm(String zsxmdm) {
        this.zsxmdm = zsxmdm;
    }

    public String getZspmdm() {
        return zspmdm;
    }

    public void setZspmdm(String zspmdm) {
        this.zspmdm = zspmdm;
    }

    public String getZszmdm() {
        return zszmdm;
    }

    public void setZszmdm(String zszmdm) {
        this.zszmdm = zszmdm;
    }

    public String getZsxmmc() {
        return zsxmmc;
    }

    public void setZsxmmc(String zsxmmc) {
        this.zsxmmc = zsxmmc;
    }

    public String getZspmmc() {
        return zspmmc;
    }

    public void setZspmmc(String zspmmc) {
        this.zspmmc = zspmmc;
    }

    public String getZszmmc() {
        return zszmmc;
    }

    public void setZszmmc(String zszmmc) {
        this.zszmmc = zszmmc;
    }

    public String getJsyj() {
        return jsyj;
    }

    public void setJsyj(String jsyj) {
        this.jsyj = jsyj;
    }

    public String getSl1() {
        return sl1;
    }

    public void setSl1(String sl1) {
        this.sl1 = sl1;
    }

    public String getSjje() {
        return sjje;
    }

    public void setSjje(String sjje) {
        this.sjje = sjje;
    }

    public String getZgswskfjdm() {
        return zgswskfjdm;
    }

    public void setZgswskfjdm(String zgswskfjdm) {
        this.zgswskfjdm = zgswskfjdm;
    }

    public String getZsswjgdm() {
        return zsswjgdm;
    }

    public void setZsswjgdm(String zsswjgdm) {
        this.zsswjgdm = zsswjgdm;
    }

    public String getSkssswjgdm() {
        return skssswjgdm;
    }

    public void setSkssswjgdm(String skssswjgdm) {
        this.skssswjgdm = skssswjgdm;
    }

    public String getZgswskfjmc() {
        return zgswskfjmc;
    }

    public void setZgswskfjmc(String zgswskfjmc) {
        this.zgswskfjmc = zgswskfjmc;
    }

    public String getZsswjgmc() {
        return zsswjgmc;
    }

    public void setZsswjgmc(String zsswjgmc) {
        this.zsswjgmc = zsswjgmc;
    }

    public String getSkssswjgmc() {
        return skssswjgmc;
    }

    public void setSkssswjgmc(String skssswjgmc) {
        this.skssswjgmc = skssswjgmc;
    }

    public String getKjrq() {
        return kjrq;
    }

    public void setKjrq(String kjrq) {
        this.kjrq = kjrq;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }
}

==> estateplat-common-1.2.4-20220523.023414-1027-sources.jar: cn/gtmap/estateplat/model/exchange/share/GxYhWsxx.java <==
package cn.gtmap.estateplat.model.exchange.share;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;

@Table(name = "GX_YH_WSXX")
public class GxYhWsxx implements Serializable {
    @Id
    private String wsxxid;//主键
    private String bjbh;
    private String lrrdm;
    private String zgswskfjdm;
    private String zsswjgmc;
    private String skssswjgdm;
    private String zsxmmc;
    private String yjse;
    private String skssqz;
    private String pzzgdm;
    private String zsswjgdm;
    private String zrfcsfbz;
    private String skssswjgmc;
    private String zszmdm;
    private String tpr;
    private String bz;
    private String dzsphm;
    private String nsrsbh;
    private String zspmmc;
    private String zszmmc;
    private String kssl;
    private String pzhm;
    private String zspmdm;
    private Double sl1;
    private String xtsphm;
    private String nsrmc;
    private String zgswskfjmc;
    private String pzzldm;
    private String skssqq;
    private String htbh;
    private Long sjje;
    private String zsxmdm;
    private Long jsyj;
    private String kjrq;

    public String getWsxxid() {
        return wsxxid;
    }

    public void setWsxxid(String wsxxid) {
        this.wsxxid = wsxxid;
    }

    public String getXtsphm() {
        return xtsphm;
    }

    public void setXtsphm(String xtsphm) {
        this.xtsphm = xtsphm;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getDzsphm() {
        return dzsphm;
    }

    public void setDzsphm(String dzsphm) {
        this.dzsphm = dzsphm;
    }

    public String getPzzldm() {
        return pzzldm;
    }

    public void setPzzldm(String pzzldm) {
        this.pzzldm = pzzldm;
    }

    public String getPzzgdm() {
        return pzzgdm;
    }

    public void setPzzgdm(String pzzgdm) {
        this.pzzgdm = pzzgdm;
    }

    public String getPzhm() {
        return pzhm;
    }

    public void setPzhm(String pzhm) {
        this.pzhm = pzhm;
    }

    public String getSkssqq() {
        return skssqq;
    }

    public void setSkssqq(String skssqq) {
        this.skssqq = skssqq;
    }

    public String getSkssqz() {
        return skssqz;
    }

    public void setSkssqz(String skssqz) {
        this.skssqz = skssqz;
    }

    public String getZsxmdm() {
        return zsxmdm;
    }

    public void setZsxmdm(String zsxmdm) {
        this.zsxmdm = zsxmdm;
    }

    public String getZspmdm() {
        return zspmdm;
    }

    public void setZspmdm(String zspmdm) {
        this.zspmdm = zspmdm;
    }

    public String getZszmdm() {
        return zszmdm;
    }

    public void setZszmdm(String zszmdm) {
        this.zszmdm = zszmdm;
    }

    public String getZsxmmc() {
        return zsxmmc;
    }

    public void setZsxmmc(String zsxmmc) {
        this.zsxmmc = zsxmmc;
    }

    public String getZspmmc() {
        return zspmmc;
    }

    public void setZspmmc(String zspmmc) {
        this.zspmmc = zspmmc;
    }

    public String getZszmmc() {
        return zszmmc;
    }

    public void setZszmmc(String zszmmc) {
        this.zszmmc = zszmmc;
    }

    public Double getSl1() {
        return sl1;
    }

    public void setSl1(Double sl1) {
        this.sl1 = sl1;
    }

    public String getZgswskfjdm() {
        return zgswskfjdm;
    }

    public void setZgswskfjdm(String zgswskfjdm) {
        this.zgswskfjdm = zgswskfjdm;
    }

    public String getZsswjgdm() {
        return zsswjgdm;
    }

    public void setZsswjgdm(String zsswjgdm) {
        this.zsswjgdm = zsswjgdm;
    }

    public String getSkssswjgdm() {
        return skssswjgdm;
    }

    public void setSkssswjgdm(String skssswjgdm) {
        this.skssswjgdm = skssswjgdm;
    }

    public String getZgswskfjmc() {
        return zgswskfjmc;
    }

    public void setZgswskfjmc(String zgswskfjmc) {
        this.zgswskfjmc = zgswskfjmc;
    }

    public String getZsswjgmc() {
        return zsswjgmc;
    }

    public void setZsswjgmc(String zsswjgmc) {
        this.zsswjgmc = zsswjgmc;
    }

    public String getSkssswjgmc() {
        return skssswjgmc;
    }

    public void setSkssswjgmc(String skssswjgmc) {
        this.skssswjgmc = skssswjgmc;
    }

    public String getKjrq() {
        return kjrq;
    }

    public void setKjrq(String kjrq) {
        this.kjrq = kjrq;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBjbh() {
        return bjbh;
    }

    public void setBjbh(String bjbh) {
        this.bjbh = bjbh;
    }

    public String getLrrdm() {
        return lrrdm;
    }

    public void setLrrdm(String lrrdm) {
        this.lrrdm = lrrdm;
    }

    public String getYjse() {
        return yjse;
    }

    public void setYjse(String yjse) {
        this.yjse = yjse;
    }

    public String getZrfcsfbz() {
        return zrfcsfbz;
    }

    public void setZrfcsfbz(String zrfcsfbz) {
        this.zrfcsfbz = zrfcsfbz;
    }

    public String getTpr() {
        return tpr;
    }

    public void setTpr(String tpr) {
        this.tpr = tpr;
    }

    public String getKssl() {
        return kssl;
    }

    public void setKssl(String kssl) {
        this.kssl = kssl;
    }

    public Long getSjje() {
        return sjje;
    }

    public void setSjje(Long sjje) {
        this.sjje = sjje;
    }

    public Long getJsyj() {
        return jsyj;
    }

    public void setJsyj(Long jsyj) {
        this.jsyj = jsyj;
    }
}
